@@ -275,6 +275,8 @@ void DolphinMainWindow::openNewTab(const KUrl& url)
     viewTab.primaryView->view()->reload();
 
     m_viewTab.append(viewTab);
+    
+    actionCollection()->action("close_tab")->setEnabled(true);
 }
 
 void DolphinMainWindow::toggleActiveView()
@@ -702,7 +704,7 @@ void DolphinMainWindow::closeTab(int index)
     if (index == m_tabIndex) {
         // The tab that should be closed is the active tab. Activate the
         // previous tab before closing the tab.
-        setActiveTab((index > 0) ? index - 1 : 1);
+        m_tabBar->setCurrentIndex((index > 0) ? index - 1 : 1);
     }
 
     // delete tab
@@ -724,7 +726,8 @@ void DolphinMainWindow::closeTab(int index)
     // if only one tab is left, also remove the tab entry so that
     // closing the last tab is not possible
     if (m_viewTab.count() == 1) {
-        m_tabBar->removeTab(0);
+        m_tabBar->removeTab(0);   
+        actionCollection()->action("close_tab")->setEnabled(false);
     } else {
         m_tabBar->blockSignals(false);
     }
@@ -831,10 +834,8 @@ void DolphinMainWindow::init()
     setupDockWidgets();
 
     setupGUI(Keys | Save | Create | ToolBar);
-    createGUI();
 
     stateChanged("new_file");
-    setAutoSaveSettings();
 
     QClipboard* clipboard = QApplication::clipboard();
     connect(clipboard, SIGNAL(dataChanged()),
@@ -914,6 +915,7 @@ void DolphinMainWindow::setupActions()
 
     QAction* closeTab = new QAction(KIcon("tab-close"), i18nc("@action:inmenu File", "Close Tab"), this);
     closeTab->setShortcut(Qt::CTRL | Qt::Key_W);
+    closeTab->setEnabled(false);
     connect(closeTab, SIGNAL(triggered()), this, SLOT(closeTab()));
     actionCollection()->addAction("close_tab", closeTab);
 
