@@ -275,7 +275,7 @@ public:
    */
   virtual void setActivePart( KParts::Part *part, QWidget *widget = 0 );
 
-  void setActivePart( KParts::Part *part, bool immediate );
+  void doSetActivePart( KParts::Part *part );
 
   void showProfileDlg( const QString & preselectProfile );
 
@@ -292,12 +292,21 @@ public:
 
   void showHTML(bool b);
 
+    /**
+     * Normalize the name of the .rc file to use; this is just
+     * for handling compatibility with old profiles mentionning
+     * konq-webbrowsing.rc or konq-filemanagement.rc
+     */
+    static QString normalizedXMLFileName(const QString& xmluiFile);
 
     /**
      * Creates a copy of the current window
      */
     KonqMainWindow* duplicateWindow();
 
+    /**
+     * Open a saved window in a new KonqMainWindow instance.
+     */
     static KonqMainWindow *openSavedWindow(const KConfigGroup& configGroup);
 
 public Q_SLOTS:
@@ -305,7 +314,7 @@ public Q_SLOTS:
      * Opens a previously closed window in a new window
      */
     static void openClosedWindow(const KonqClosedWindowItem& closedTab);
-    
+
     /**
      * Opens a previously closed tab in a new tab
      */
